@@ -238,8 +238,13 @@ static gboolean dvdnavsrc_convert (GstPad * pad,
 static gboolean dvdnavsrc_close (DVDNavSrc * src);
 static gboolean dvdnavsrc_open (DVDNavSrc * src);
 static gboolean dvdnavsrc_is_open (DVDNavSrc * src);
+
+#ifndef GST_DISABLE_GST_DEBUG
 static void dvdnavsrc_print_event (DVDNavSrc * src,
     guint8 * data, int event, int len);
+#else
+#define dvdnavsrc_print_event(src, data, event, len) ((void) 0)
+#endif /* GST_DISABLE_GST_DEBUG */
 static void dvdnavsrc_update_streaminfo (DVDNavSrc * src);
 static void dvdnavsrc_set_domain (DVDNavSrc * src);
 static void dvdnavsrc_update_highlight (DVDNavSrc * src);
@@ -1029,9 +1034,6 @@ dvdnav_get_event_name (int event)
   }
   return "UNKNOWN";
 }
-#else
-#define dvdnav_get_event_name(event) "<unknown>"
-#endif /* GST_DISABLE_GST_DEBUG */
 
 static gchar *
 dvdnav_get_read_domain_name (dvd_read_domain_t domain)
@@ -1053,7 +1055,6 @@ dvdnav_get_read_domain_name (dvd_read_domain_t domain)
   return "UNKNOWN";
 }
 
-#ifndef GST_DISABLE_GST_DEBUG
 static void
 dvdnavsrc_print_event (DVDNavSrc * src, guint8 * data, int event, int len)
 {
@@ -1149,8 +1150,6 @@ dvdnavsrc_print_event (DVDNavSrc * src, guint8 * data, int event, int len)
       break;
   }
 }
-#else
-#define dvdnavsrc_print_event(src, data, event, len) ((void) 0)
 #endif /* GST_DISABLE_GST_DEBUG */
 
 static GstEvent *
@@ -1191,8 +1190,7 @@ dvdnavsrc_make_dvd_nav_packet_event (DVDNavSrc * src, const pci_t * pci)
 {
   GstEvent *event;
   GstStructure *structure;
-  GValue start_ptm = { 0 }, end_ptm =
-  {
+  GValue start_ptm = { 0 }, end_ptm = {
   0};
 
   /* Store the time values in GValues. */
@@ -1632,7 +1630,7 @@ dvdnav_handle_navigation_event (DVDNavSrc * src, GstEvent * event)
     const char *key = gst_structure_get_string (structure, "key");
 
     g_assert (key != NULL);
-    g_print ("dvdnavsrc got a keypress: %s", key);
+    GST_DEBUG ("dvdnavsrc got a keypress: %s", key);
   } else if (strcmp (event_type, "mouse-move") == 0) {
     double x, y;
 
