@@ -23,92 +23,50 @@
 
 #include "gstfaac.h"
 
-GST_PAD_TEMPLATE_FACTORY (src_template,
-  "src",
-  GST_PAD_SRC,
-  GST_PAD_ALWAYS,
-  GST_CAPS_NEW (
-    "faac_mpeg_templ",
-    "audio/mpeg",
-      "systemstream", GST_PROPS_BOOLEAN (FALSE),
-      "mpegversion",  GST_PROPS_LIST (
-                        GST_PROPS_INT (4), /* we prefer 4 */
-                        GST_PROPS_INT (2)
-                      ),
-      "channels",     GST_PROPS_INT_RANGE (1, 6),
-      "samplerate",   GST_PROPS_INT_RANGE (8000, 96000)
-  )
-);
+static GstStaticPadTemplate src_template = GST_STATIC_PAD_TEMPLATE ("src",
+    GST_PAD_SRC,
+    GST_PAD_ALWAYS,
+    GST_STATIC_CAPS ("audio/mpeg, "
+        "mpegversion = (int) { 4, 2 }, "
+        "channels = (int) [ 1, 6 ], " "rate = (int) [ 8000, 96000 ]")
+    );
 
-GST_PAD_TEMPLATE_FACTORY (sink_template,
-  "sink",
-  GST_PAD_SINK,
-  GST_PAD_ALWAYS,
-  GST_CAPS_NEW (
-    "faac_int16_templ",
-    "audio/x-raw-int",
-      "endianness", GST_PROPS_INT (G_BYTE_ORDER),
-      "signed",     GST_PROPS_BOOLEAN (TRUE),
-      "width",      GST_PROPS_INT (16),
-      "depth",      GST_PROPS_INT (16),
-      "rate",       GST_PROPS_INT_RANGE (8000, 96000),
-      "channels",   GST_PROPS_INT_RANGE (1, 6)
-  ),
-  GST_CAPS_NEW (
-    "faac_int24_templ",
-    "audio/x-raw-int",
-      "endianness", GST_PROPS_INT (G_BYTE_ORDER),
-      "signed",     GST_PROPS_BOOLEAN (TRUE),
-      "width",      GST_PROPS_INT (32),
-      "depth",      GST_PROPS_INT (24),
-      "rate",       GST_PROPS_INT_RANGE (8000, 96000),
-      "channels",   GST_PROPS_INT_RANGE (1, 6)
-  ),
-  GST_CAPS_NEW (
-    "faac_float_templ",
-    "audio/x-raw-float",
-      "endianness", GST_PROPS_INT (G_BYTE_ORDER),
-      "depth",      GST_PROPS_INT (32), /* float  */
-      "rate",       GST_PROPS_INT_RANGE (8000, 96000),
-      "channels",   GST_PROPS_INT_RANGE (1, 6)
-  )
-);
+static GstStaticPadTemplate sink_template = GST_STATIC_PAD_TEMPLATE ("sink",
+    GST_PAD_SINK,
+    GST_PAD_ALWAYS,
+    GST_STATIC_CAPS ("audio/x-raw-int, " "endianness = (int) BYTE_ORDER, " "signed = (boolean) TRUE, " "width = (int) 16, " "depth = (int) 16, " "rate = (int) [ 8000, 96000 ], " "channels = (int) [ 1, 6]; " "audio/x-raw-int, " "endianness = (int) BYTE_ORDER, " "signed = (boolean) TRUE, " "width = (int) 32, " "depth = (int) 24, " "rate = (int) [ 8000, 96000], " "channels = (int) [ 1, 6]; " "audio/x-raw-float, " "endianness = (int) BYTE_ORDER, " "depth = (int) 32, "    /* sizeof (gfloat) */
+        "rate = (int) [ 8000, 96000], " "channels = (int) [ 1, 6]")
+    );
 
-enum {
+enum
+{
   ARG_0,
   ARG_BITRATE,
   ARG_PROFILE,
   ARG_TNS,
   ARG_MIDSIDE,
   ARG_SHORTCTL
-  /* FILL ME */
+      /* FILL ME */
 };
 
-static void     gst_faac_base_init    (GstFaacClass *klass);
-static void     gst_faac_class_init   (GstFaacClass *klass);
-static void     gst_faac_init         (GstFaac      *faac);
+static void gst_faac_base_init (GstFaacClass * klass);
+static void gst_faac_class_init (GstFaacClass * klass);
+static void gst_faac_init (GstFaac * faac);
 
-static void     gst_faac_set_property (GObject      *object,
-				       guint         prop_id, 
-				       const GValue *value,
-				       GParamSpec   *pspec);
-static void     gst_faac_get_property (GObject      *object,
-				       guint         prop_id, 
-				       GValue       *value,
-				       GParamSpec   *pspec);
+static void gst_faac_set_property (GObject * object,
+    guint prop_id, const GValue * value, GParamSpec * pspec);
+static void gst_faac_get_property (GObject * object,
+    guint prop_id, GValue * value, GParamSpec * pspec);
 
 static GstPadLinkReturn
-                gst_faac_sinkconnect  (GstPad       *pad,
-				       GstCaps      *caps);
+gst_faac_sinkconnect (GstPad * pad, const GstCaps * caps);
 static GstPadLinkReturn
-                gst_faac_srcconnect   (GstPad       *pad,
-				       GstCaps      *caps);
-static void     gst_faac_chain        (GstPad       *pad,
-				       GstData      *data);
-static GstElementStateReturn
-                gst_faac_change_state (GstElement   *element);
+gst_faac_srcconnect (GstPad * pad, const GstCaps * caps);
+static void gst_faac_chain (GstPad * pad, GstData * data);
+static GstElementStateReturn gst_faac_change_state (GstElement * element);
 
 static GstElementClass *parent_class = NULL;
+
 /* static guint gst_faac_signals[LAST_SIGNAL] = { 0 }; */
 
 GType
@@ -118,40 +76,39 @@ gst_faac_get_type (void)
 
   if (!gst_faac_type) {
     static const GTypeInfo gst_faac_info = {
-      sizeof (GstFaacClass),      
+      sizeof (GstFaacClass),
       (GBaseInitFunc) gst_faac_base_init,
       NULL,
       (GClassInitFunc) gst_faac_class_init,
       NULL,
       NULL,
-      sizeof(GstFaac),
+      sizeof (GstFaac),
       0,
       (GInstanceInitFunc) gst_faac_init,
     };
 
     gst_faac_type = g_type_register_static (GST_TYPE_ELEMENT,
-					    "GstFaac",
-					    &gst_faac_info, 0);
+        "GstFaac", &gst_faac_info, 0);
   }
 
   return gst_faac_type;
 }
 
 static void
-gst_faac_base_init (GstFaacClass *klass)
+gst_faac_base_init (GstFaacClass * klass)
 {
   GstElementDetails gst_faac_details = {
     "Free AAC Encoder (FAAC)",
-    "Codec/Audio/Encoder",
+    "Codec/Encoder/Audio",
     "Free MPEG-2/4 AAC encoder",
     "Ronald Bultje <rbultje@ronald.bitfreak.net>",
   };
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
   gst_element_class_add_pad_template (element_class,
-	GST_PAD_TEMPLATE_GET (src_template));
+      gst_static_pad_template_get (&src_template));
   gst_element_class_add_pad_template (element_class,
-	GST_PAD_TEMPLATE_GET (sink_template));
+      gst_static_pad_template_get (&sink_template));
 
   gst_element_class_set_details (element_class, &gst_faac_details);
 }
@@ -164,15 +121,15 @@ gst_faac_profile_get_type (void)
 
   if (!gst_faac_profile_type) {
     static GEnumValue gst_faac_profile[] = {
-      { MAIN, "MAIN", "Main profile"                   },
-      { LOW,  "LOW",  "Low complexity profile"         },
-      { SSR,  "SSR",  "Scalable sampling rate profile" },
-      { LTP,  "LTP",  "Long term prediction profile"   },
-      { 0, NULL, NULL },
+      {MAIN, "MAIN", "Main profile"},
+      {LOW, "LOW", "Low complexity profile"},
+      {SSR, "SSR", "Scalable sampling rate profile"},
+      {LTP, "LTP", "Long term prediction profile"},
+      {0, NULL, NULL},
     };
 
     gst_faac_profile_type = g_enum_register_static ("GstFaacProfile",
-						    gst_faac_profile);
+        gst_faac_profile);
   }
 
   return gst_faac_profile_type;
@@ -186,21 +143,21 @@ gst_faac_shortctl_get_type (void)
 
   if (!gst_faac_shortctl_type) {
     static GEnumValue gst_faac_shortctl[] = {
-      { SHORTCTL_NORMAL,  "SHORTCTL_NORMAL",  "Normal block type" },
-      { SHORTCTL_NOSHORT, "SHORTCTL_NOSHORT", "No short blocks"   },
-      { SHORTCTL_NOLONG,  "SHORTCTL_NOLONG",  "No long blocks"    },
-      { 0, NULL, NULL },
+      {SHORTCTL_NORMAL, "SHORTCTL_NORMAL", "Normal block type"},
+      {SHORTCTL_NOSHORT, "SHORTCTL_NOSHORT", "No short blocks"},
+      {SHORTCTL_NOLONG, "SHORTCTL_NOLONG", "No long blocks"},
+      {0, NULL, NULL},
     };
 
     gst_faac_shortctl_type = g_enum_register_static ("GstFaacShortCtl",
-						    gst_faac_shortctl);
+        gst_faac_shortctl);
   }
 
   return gst_faac_shortctl_type;
 }
 
 static void
-gst_faac_class_init (GstFaacClass *klass)
+gst_faac_class_init (GstFaacClass * klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   GstElementClass *gstelement_class = GST_ELEMENT_CLASS (klass);
@@ -209,21 +166,21 @@ gst_faac_class_init (GstFaacClass *klass)
 
   /* properties */
   g_object_class_install_property (gobject_class, ARG_BITRATE,
-    g_param_spec_int ("bitrate", "Bitrate (bps)", "Bitrate in bits/sec",
-                      8 * 1024, 320 * 1024, 128 * 1024, G_PARAM_READWRITE));
+      g_param_spec_int ("bitrate", "Bitrate (bps)", "Bitrate in bits/sec",
+          8 * 1024, 320 * 1024, 128 * 1024, G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class, ARG_PROFILE,
-    g_param_spec_enum ("profile", "Profile", "MPEG/AAC encoding profile",
-                       GST_TYPE_FAAC_PROFILE, MAIN, G_PARAM_READWRITE));
+      g_param_spec_enum ("profile", "Profile", "MPEG/AAC encoding profile",
+          GST_TYPE_FAAC_PROFILE, MAIN, G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class, ARG_TNS,
-    g_param_spec_boolean ("tns", "TNS", "Use temporal noise shaping",
-                          FALSE, G_PARAM_READWRITE));
+      g_param_spec_boolean ("tns", "TNS", "Use temporal noise shaping",
+          FALSE, G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class, ARG_MIDSIDE,
-    g_param_spec_boolean ("midside", "Midside", "Allow mid/side encoding",
-                          TRUE, G_PARAM_READWRITE));
+      g_param_spec_boolean ("midside", "Midside", "Allow mid/side encoding",
+          TRUE, G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class, ARG_SHORTCTL,
-    g_param_spec_enum ("shortctl", "Block type",
-		       "Block type encorcing",
-                       GST_TYPE_FAAC_SHORTCTL, MAIN, G_PARAM_READWRITE));
+      g_param_spec_enum ("shortctl", "Block type",
+          "Block type encorcing",
+          GST_TYPE_FAAC_SHORTCTL, MAIN, G_PARAM_READWRITE));
 
   /* virtual functions */
   gstelement_class->change_state = gst_faac_change_state;
@@ -233,7 +190,7 @@ gst_faac_class_init (GstFaacClass *klass)
 }
 
 static void
-gst_faac_init (GstFaac *faac)
+gst_faac_init (GstFaac * faac)
 {
   faac->handle = NULL;
   faac->samplerate = -1;
@@ -244,14 +201,16 @@ gst_faac_init (GstFaac *faac)
 
   GST_FLAG_SET (faac, GST_ELEMENT_EVENT_AWARE);
 
-  faac->sinkpad = gst_pad_new_from_template (
-	GST_PAD_TEMPLATE_GET (sink_template), "sink");
+  faac->sinkpad =
+      gst_pad_new_from_template (gst_static_pad_template_get (&sink_template),
+      "sink");
   gst_element_add_pad (GST_ELEMENT (faac), faac->sinkpad);
   gst_pad_set_chain_function (faac->sinkpad, gst_faac_chain);
   gst_pad_set_link_function (faac->sinkpad, gst_faac_sinkconnect);
 
-  faac->srcpad = gst_pad_new_from_template (
-	GST_PAD_TEMPLATE_GET (src_template), "src");
+  faac->srcpad =
+      gst_pad_new_from_template (gst_static_pad_template_get (&src_template),
+      "src");
   gst_element_add_pad (GST_ELEMENT (faac), faac->srcpad);
   gst_pad_set_link_function (faac->srcpad, gst_faac_srcconnect);
 
@@ -264,12 +223,15 @@ gst_faac_init (GstFaac *faac)
 }
 
 static GstPadLinkReturn
-gst_faac_sinkconnect (GstPad  *pad,
-		      GstCaps *caps)
+gst_faac_sinkconnect (GstPad * pad, const GstCaps * caps)
 {
   GstFaac *faac = GST_FAAC (gst_pad_get_parent (pad));
+  GstStructure *structure = gst_caps_get_structure (caps, 0);
+  faacEncHandle *handle;
+  gint channels, samplerate, depth;
+  gulong samples, bytes, fmt = 0, bps = 0;
 
-  if (!GST_CAPS_IS_FIXED (caps))
+  if (!gst_caps_is_fixed (caps))
     return GST_PAD_LINK_DELAYED;
 
   if (faac->handle) {
@@ -281,87 +243,79 @@ gst_faac_sinkconnect (GstPad  *pad,
     faac->cache = NULL;
   }
 
-  for (; caps != NULL; caps = caps->next) {
-    faacEncHandle *handle;
-    gint channels, samplerate, depth;
-    gulong samples, bytes, fmt = 0, bps = 0;
+  gst_structure_get_int (structure, "channels", &channels);
+  gst_structure_get_int (structure, "rate", &samplerate);
+  gst_structure_get_int (structure, "depth", &depth);
 
-    gst_caps_get (caps, "channels", &channels,
-			"rate",     &samplerate,
-			"depth",    &depth, NULL);
+  /* open a new handle to the encoder */
+  if (!(handle = faacEncOpen (samplerate, channels, &samples, &bytes)))
+    return GST_PAD_LINK_REFUSED;
 
-    /* open a new handle to the encoder */
-    if (!(handle = faacEncOpen (samplerate, channels,
-				&samples, &bytes)))
-      continue;
-
-    switch (depth) {
-      case 16:
-        fmt = FAAC_INPUT_16BIT;
-        bps = 2;
-        break;
-      case 24:
-        fmt = FAAC_INPUT_32BIT; /* 24-in-32, actually */
-        bps = 4;
-        break;
-      case 32:
-        fmt = FAAC_INPUT_FLOAT; /* see template, this is right */
-        bps = 4;
-        break;
-    }
-
-    if (!fmt) {
-      faacEncClose (handle);
-      continue;
-    }
-
-    faac->format = fmt;
-    faac->bps = bps;
-    faac->handle = handle;
-    faac->bytes = bytes;
-    faac->samples = samples;
-    faac->channels = channels;
-    faac->samplerate = samplerate;
-
-    /* if the other side was already set-up, redo that */
-    if (GST_PAD_CAPS (faac->srcpad))
-      return gst_faac_srcconnect (faac->srcpad,
-				  gst_pad_get_allowed_caps (faac->srcpad));
-
-    /* else, that'll be done later */
-    return GST_PAD_LINK_OK;
+  switch (depth) {
+    case 16:
+      fmt = FAAC_INPUT_16BIT;
+      bps = 2;
+      break;
+    case 24:
+      fmt = FAAC_INPUT_32BIT;   /* 24-in-32, actually */
+      bps = 4;
+      break;
+    case 32:
+      fmt = FAAC_INPUT_FLOAT;   /* see template, this is right */
+      bps = 4;
+      break;
   }
 
-  return GST_PAD_LINK_REFUSED;
+  if (!fmt) {
+    faacEncClose (handle);
+    return GST_PAD_LINK_REFUSED;
+  }
+
+  faac->format = fmt;
+  faac->bps = bps;
+  faac->handle = handle;
+  faac->bytes = bytes;
+  faac->samples = samples;
+  faac->channels = channels;
+  faac->samplerate = samplerate;
+
+  /* if the other side was already set-up, redo that */
+  if (GST_PAD_CAPS (faac->srcpad))
+    return gst_faac_srcconnect (faac->srcpad,
+        gst_pad_get_allowed_caps (faac->srcpad));
+
+  /* else, that'll be done later */
+  return GST_PAD_LINK_OK;
 }
 
 static GstPadLinkReturn
-gst_faac_srcconnect (GstPad  *pad,
-		     GstCaps *caps)
+gst_faac_srcconnect (GstPad * pad, const GstCaps * caps)
 {
   GstFaac *faac = GST_FAAC (gst_pad_get_parent (pad));
-  GstCaps *t;
+  gint n;
 
-  if (!faac->handle ||
-      (faac->samplerate == -1 || faac->channels == -1)) {
+  if (!faac->handle || (faac->samplerate == -1 || faac->channels == -1)) {
     return GST_PAD_LINK_DELAYED;
   }
 
   /* we do samplerate/channels ourselves */
-  for (t = caps; t != NULL; t = t->next) {
-    gst_props_remove_entry_by_name (t->properties, "rate");
-    gst_props_remove_entry_by_name (t->properties, "channels");
+  for (n = 0; n < gst_caps_get_size (caps); n++) {
+    GstStructure *structure = gst_caps_get_structure (caps, n);
+
+    gst_structure_remove_field (structure, "rate");
+    gst_structure_remove_field (structure, "channels");
   }
 
   /* go through list */
   caps = gst_caps_normalize (caps);
-  for ( ; caps != NULL; caps = caps->next) {
+  for (n = 0; n < gst_caps_get_size (caps); n++) {
+    GstStructure *structure = gst_caps_get_structure (caps, n);
     faacEncConfiguration *conf;
     gint mpegversion = 0;
     GstCaps *newcaps;
     GstPadLinkReturn ret;
 
-    gst_caps_get_int (caps, "mpegversion", &mpegversion);
+    gst_structure_get_int (structure, "mpegversion", &mpegversion);
 
     /* new conf */
     conf = faacEncGetCurrentConfiguration (faac->handle);
@@ -381,19 +335,17 @@ gst_faac_srcconnect (GstPad  *pad,
      * that (that the next element is filesink or any element
      * that does want ADTS headers). */
 
-    conf->outputFormat = 0; /* raw, no ADTS headers */
+    conf->outputFormat = 0;     /* raw, no ADTS headers */
     conf->shortctl = faac->shortctl;
     if (!faacEncSetConfiguration (faac->handle, conf)) {
       GST_WARNING ("Faac doesn't support the current conf");
       continue;
     }
 
-    newcaps = GST_CAPS_NEW ("faac_mpeg_caps",
-			    "audio/mpeg",
-			      "systemstream", GST_PROPS_BOOLEAN (FALSE),
-			      "mpegversion",  GST_PROPS_INT (mpegversion),
-			      "channels",     GST_PROPS_INT (faac->channels),
-			      "rate",         GST_PROPS_INT (faac->samplerate));
+    newcaps = gst_caps_new_simple ("audio/mpeg",
+        "mpegversion", G_TYPE_INT, mpegversion,
+        "channels", G_TYPE_INT, faac->channels,
+        "rate", G_TYPE_INT, faac->samplerate, NULL);
     ret = gst_pad_try_set_caps (faac->srcpad, newcaps);
 
     switch (ret) {
@@ -411,8 +363,7 @@ gst_faac_srcconnect (GstPad  *pad,
 }
 
 static void
-gst_faac_chain (GstPad  *pad,
-		GstData *data)
+gst_faac_chain (GstPad * pad, GstData * data)
 {
   GstFaac *faac = GST_FAAC (gst_pad_get_parent (pad));
   GstBuffer *inbuf, *outbuf, *subbuf;
@@ -427,10 +378,8 @@ gst_faac_chain (GstPad  *pad,
         while (1) {
           outbuf = gst_buffer_new_and_alloc (faac->bytes);
           if ((ret_size = faacEncEncode (faac->handle,
-					 NULL, 0,
-					 GST_BUFFER_DATA (outbuf),
-					 faac->bytes)) < 0) {
-            gst_element_error (GST_ELEMENT (faac), "Error during AAC encoding");
+                      NULL, 0, GST_BUFFER_DATA (outbuf), faac->bytes)) < 0) {
+            GST_ELEMENT_ERROR (faac, LIBRARY, ENCODE, (NULL), (NULL));
             gst_event_unref (event);
             gst_buffer_unref (outbuf);
             return;
@@ -450,7 +399,7 @@ gst_faac_chain (GstPad  *pad,
         gst_pad_push (faac->srcpad, data);
         return;
       default:
-	gst_pad_event_default (pad, event);
+        gst_pad_event_default (pad, event);
         return;
     }
   }
@@ -458,17 +407,17 @@ gst_faac_chain (GstPad  *pad,
   inbuf = GST_BUFFER (data);
 
   if (!faac->handle) {
-    gst_element_error (GST_ELEMENT (faac),
-		       "No input format negotiated");
+    GST_ELEMENT_ERROR (faac, CORE, NEGOTIATION, (NULL),
+        ("format wasn't negotiated before chain function"));
     gst_buffer_unref (inbuf);
     return;
   }
 
   if (!GST_PAD_CAPS (faac->srcpad)) {
     if (gst_faac_srcconnect (faac->srcpad,
-			     gst_pad_get_allowed_caps (faac->srcpad)) <= 0) {
-      gst_element_error (GST_ELEMENT (faac),
-			 "Failed to negotiate MPEG/AAC format with next element");
+            gst_pad_get_allowed_caps (faac->srcpad)) <= 0) {
+      GST_ELEMENT_ERROR (faac, CORE, NEGOTIATION, (NULL),
+          ("failed to negotiate MPEG/AAC format with next element"));
       gst_buffer_unref (inbuf);
       return;
     }
@@ -484,52 +433,60 @@ gst_faac_chain (GstPad  *pad,
     /* do we have enough data for one frame? */
     if (in_size / faac->bps < faac->samples) {
       if (in_size > size) {
+        GstBuffer *merge;
+
         /* this is panic! we got a buffer, but still don't have enough
          * data. Merge them and retry in the next cycle... */
-        faac->cache = gst_buffer_merge (faac->cache, inbuf);
+        merge = gst_buffer_merge (faac->cache, inbuf);
+        gst_buffer_unref (faac->cache);
+        gst_buffer_unref (inbuf);
+        faac->cache = merge;
       } else if (in_size == size) {
         /* this shouldn't happen, but still... */
         faac->cache = inbuf;
       } else if (in_size > 0) {
-        faac->cache = gst_buffer_create_sub (inbuf, size - in_size,
-					     in_size);
+        faac->cache = gst_buffer_create_sub (inbuf, size - in_size, in_size);
         GST_BUFFER_DURATION (faac->cache) =
-	  GST_BUFFER_DURATION (inbuf) * GST_BUFFER_SIZE (faac->cache) / size;
+            GST_BUFFER_DURATION (inbuf) * GST_BUFFER_SIZE (faac->cache) / size;
         GST_BUFFER_TIMESTAMP (faac->cache) =
-	  GST_BUFFER_TIMESTAMP (inbuf) + (GST_BUFFER_DURATION (inbuf) *
-	    (size - in_size) / size);
+            GST_BUFFER_TIMESTAMP (inbuf) + (GST_BUFFER_DURATION (inbuf) *
+            (size - in_size) / size);
         gst_buffer_unref (inbuf);
       } else {
         gst_buffer_unref (inbuf);
       }
-          
+
       return;
     }
 
     /* create the frame */
     if (in_size > size) {
+      GstBuffer *merge;
+
       /* merge */
       subbuf = gst_buffer_create_sub (inbuf, 0, frame_size - (in_size - size));
       GST_BUFFER_DURATION (subbuf) =
-	GST_BUFFER_DURATION (inbuf) * GST_BUFFER_SIZE (subbuf) / size;
-      subbuf = gst_buffer_merge (faac->cache, subbuf);
+          GST_BUFFER_DURATION (inbuf) * GST_BUFFER_SIZE (subbuf) / size;
+      merge = gst_buffer_merge (faac->cache, subbuf);
+      gst_buffer_unref (faac->cache);
+      gst_buffer_unref (subbuf);
+      subbuf = merge;
       faac->cache = NULL;
     } else {
       subbuf = gst_buffer_create_sub (inbuf, size - in_size, frame_size);
       GST_BUFFER_DURATION (subbuf) =
-	GST_BUFFER_DURATION (inbuf) * GST_BUFFER_SIZE (subbuf) / size;
+          GST_BUFFER_DURATION (inbuf) * GST_BUFFER_SIZE (subbuf) / size;
       GST_BUFFER_TIMESTAMP (subbuf) =
-	GST_BUFFER_TIMESTAMP (inbuf) + (GST_BUFFER_DURATION (inbuf) *
-	  (size - in_size) / size);
+          GST_BUFFER_TIMESTAMP (inbuf) + (GST_BUFFER_DURATION (inbuf) *
+          (size - in_size) / size);
     }
 
     outbuf = gst_buffer_new_and_alloc (faac->bytes);
     if ((ret_size = faacEncEncode (faac->handle,
-				   (gint32 *) GST_BUFFER_DATA (subbuf),
-				   GST_BUFFER_SIZE (subbuf) / faac->bps,
-				   GST_BUFFER_DATA (outbuf),
-				   faac->bytes)) < 0) {
-      gst_element_error (GST_ELEMENT (faac), "Error during AAC encoding");
+                (gint32 *) GST_BUFFER_DATA (subbuf),
+                GST_BUFFER_SIZE (subbuf) / faac->bps,
+                GST_BUFFER_DATA (outbuf), faac->bytes)) < 0) {
+      GST_ELEMENT_ERROR (faac, LIBRARY, ENCODE, (NULL), (NULL));
       gst_buffer_unref (inbuf);
       gst_buffer_unref (subbuf);
       return;
@@ -569,10 +526,8 @@ gst_faac_chain (GstPad  *pad,
 }
 
 static void
-gst_faac_set_property (GObject      *object,
-		       guint         prop_id, 
-		       const GValue *value,
-		       GParamSpec   *pspec)
+gst_faac_set_property (GObject * object,
+    guint prop_id, const GValue * value, GParamSpec * pspec)
 {
   GstFaac *faac = GST_FAAC (object);
 
@@ -599,10 +554,8 @@ gst_faac_set_property (GObject      *object,
 }
 
 static void
-gst_faac_get_property (GObject    *object,
-		       guint       prop_id, 
-		       GValue     *value,
-		       GParamSpec *pspec)
+gst_faac_get_property (GObject * object,
+    guint prop_id, GValue * value, GParamSpec * pspec)
 {
   GstFaac *faac = GST_FAAC (object);
 
@@ -629,7 +582,7 @@ gst_faac_get_property (GObject    *object,
 }
 
 static GstElementStateReturn
-gst_faac_change_state (GstElement *element)
+gst_faac_change_state (GstElement * element)
 {
   GstFaac *faac = GST_FAAC (element);
 
@@ -659,21 +612,13 @@ gst_faac_change_state (GstElement *element)
 }
 
 static gboolean
-plugin_init (GstPlugin *plugin)
+plugin_init (GstPlugin * plugin)
 {
-  return gst_element_register (plugin, "faac",
-			       GST_RANK_NONE,
-			       GST_TYPE_FAAC);
+  return gst_element_register (plugin, "faac", GST_RANK_NONE, GST_TYPE_FAAC);
 }
 
-GST_PLUGIN_DEFINE (
-  GST_VERSION_MAJOR,
-  GST_VERSION_MINOR,
-  "faac",
-  "Free AAC Encoder (FAAC)",
-  plugin_init,
-  VERSION,
-  "LGPL",
-  GST_PACKAGE,
-  GST_ORIGIN
-)
+GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
+    GST_VERSION_MINOR,
+    "faac",
+    "Free AAC Encoder (FAAC)",
+    plugin_init, VERSION, "LGPL", GST_PACKAGE, GST_ORIGIN)
