@@ -57,6 +57,7 @@ struct _GstTheoraDec
   guint packetno;
   guint64 granulepos;
 
+  gboolean initialized;
   gboolean need_keyframe;
   gint width, height;
   gint offset_x, offset_y;
@@ -338,6 +339,31 @@ theora_dec_sink_convert (GstPad * pad,
       }
       break;
     }
+    case GST_FORMAT_TIME:
+    {
+      switch (*dest_format) {
+        case GST_FORMAT_DEFAULT:
+        {
+          guint ilog = _theora_ilog (dec->info.keyframe_frequency_force - 1);
+          guint rest;
+
+          /* framecount */
+          *dest_value = src_value * dec->info.fps_numerator /
+              (GST_SECOND * dec->info.fps_denominator);
+
+          /* funny way of calculating granulepos in theora */
+          rest = *dest_value / dec->info.keyframe_frequency_force;
+          *dest_value -= rest;
+          *dest_value <<= ilog;
+          *dest_value += rest;
+          break;
+        }
+        default:
+          res = FALSE;
+          break;
+      }
+      break;
+    }
     default:
       res = FALSE;
   }
@@ -391,6 +417,7 @@ theora_dec_src_event (GstPad * pad, GstEvent * event)
   switch (GST_EVENT_TYPE (event)) {
     case GST_EVENT_SEEK:{
       guint64 value;
+      GstEvent *real_seek;
 
       /* we have to ask our peer to seek to time here as we know
        * nothing about how to generate a granulepos from the src
@@ -405,7 +432,7 @@ theora_dec_src_event (GstPad * pad, GstEvent * event)
         goto error;
 
       /* then seek with time on the peer */
-      GstEvent *real_seek = gst_event_new_seek (
+      real_seek = gst_event_new_seek (
           (GST_EVENT_SEEK_TYPE (event) & ~GST_SEEK_FORMAT_MASK) |
           format, value);
 
@@ -512,15 +539,11 @@ theora_dec_chain (GstPad * pad, GstData * data)
     offset_end = GST_BUFFER_OFFSET_END (buf);
     if (offset_end != -1) {
       dec->granulepos = offset_end;
-      /* granulepos to time */
-      outtime = GST_SECOND * theora_granule_time (&dec->state, dec->granulepos);
-    } else {
-      GstFormat time_format = GST_FORMAT_TIME;
-
-      /* framenumber to time */
-      theora_dec_src_convert (dec->srcpad, GST_FORMAT_DEFAULT,
-          dec->packetno - 3, &time_format, &outtime);
     }
+
+    /* granulepos to time */
+    outtime = GST_SECOND * theora_granule_time (&dec->state, dec->granulepos);
+    dec->granulepos++;
   } else {
     /* we don't know yet */
     outtime = -1;
@@ -530,12 +553,20 @@ theora_dec_chain (GstPad * pad, GstData * data)
   packet.packet = GST_BUFFER_DATA (buf);
   packet.bytes = GST_BUFFER_SIZE (buf);
   packet.granulepos = dec->granulepos;
-  packet.packetno = dec->packetno++;
+  packet.packetno = dec->packetno;
   packet.b_o_s = (packet.packetno == 0) ? 1 : 0;
   packet.e_o_s = 0;
 
+  GST_DEBUG_OBJECT (dec, "header=%d packetno=%d, outtime=%" GST_TIME_FORMAT,
+      packet.packet[0], packet.packetno, GST_TIME_ARGS (outtime));
+
   /* switch depending on packet type */
   if (packet.packet[0] & 0x80) {
+    if (packet.packetno > 3) {
+      GST_WARNING_OBJECT (GST_OBJECT (dec), "Ignoring header");
+      gst_data_unref (data);
+      return;
+    }
     /* header packet */
     if (theora_decode_header (&dec->info, &dec->comment, &packet)) {
       GST_ELEMENT_ERROR (GST_ELEMENT (dec), STREAM, DECODE,
@@ -543,7 +574,10 @@ theora_dec_chain (GstPad * pad, GstData * data)
       gst_data_unref (data);
       return;
     }
-    if (packet.packetno == 1) {
+
+    if (packet.packetno == 0) {
+      dec->packetno++;
+    } else if (packet.packetno == 1) {
       gchar *encoder = NULL;
       GstTagList *list =
           gst_tag_list_from_vorbiscomment_buffer (buf, "\201theora", 7,
@@ -559,8 +593,12 @@ theora_dec_chain (GstPad * pad, GstData * data)
         g_free (encoder);
       }
       gst_tag_list_add (list, GST_TAG_MERGE_REPLACE,
-          GST_TAG_ENCODER_VERSION, dec->info.version_major, NULL);
+          GST_TAG_ENCODER_VERSION, dec->info.version_major,
+          GST_TAG_NOMINAL_BITRATE, dec->info.target_bitrate,
+          GST_TAG_VIDEO_CODEC, "Theora", NULL);
       gst_element_found_tags_for_pad (GST_ELEMENT (dec), dec->srcpad, 0, list);
+
+      dec->packetno++;
     } else if (packet.packetno == 2) {
       GstCaps *caps;
       gint par_num, par_den;
@@ -612,6 +650,7 @@ theora_dec_chain (GstPad * pad, GstData * data)
 
       /* done */
       theora_decode_init (&dec->state, &dec->info);
+
       caps = gst_caps_new_simple ("video/x-raw-yuv",
           "format", GST_TYPE_FOURCC, GST_MAKE_FOURCC ('I', '4', '2', '0'),
           "framerate", G_TYPE_DOUBLE,
@@ -621,6 +660,9 @@ theora_dec_chain (GstPad * pad, GstData * data)
           dec->height, NULL);
       gst_pad_set_explicit_caps (dec->srcpad, caps);
       gst_caps_free (caps);
+
+      dec->initialized = TRUE;
+      dec->packetno++;
     }
   } else {
     /* normal data packet */
@@ -633,12 +675,20 @@ theora_dec_chain (GstPad * pad, GstData * data)
     gint width, height;
     gint cwidth, cheight;
 
+    dec->packetno++;
+
+    if (!dec->initialized) {
+      gst_data_unref (data);
+      return;
+    }
+
     /* the second most significant bit of the first data byte is cleared 
      * for keyframes */
     keyframe = (packet.packet[0] & 0x40) == 0;
     if (keyframe) {
       dec->need_keyframe = FALSE;
     } else if (dec->need_keyframe) {
+      GST_WARNING_OBJECT (dec, "dropping frame because we need a keyframe");
       /* drop frames if we're looking for a keyframe */
       gst_data_unref (data);
       return;
@@ -739,6 +789,7 @@ theora_dec_change_state (GstElement * element)
       theora_info_init (&dec->info);
       theora_comment_init (&dec->comment);
       dec->need_keyframe = TRUE;
+      dec->initialized = FALSE;
       break;
     case GST_STATE_PAUSED_TO_PLAYING:
       break;
