@@ -85,10 +85,12 @@ static void gst_matroska_demux_set_clock (GstElement * element,
 /* caps functions */
 static GstCaps *gst_matroska_demux_video_caps (GstMatroskaTrackVideoContext
     * videocontext,
-    const gchar * codec_id, gpointer data, guint size, gchar ** codec_name);
+    const gchar * codec_id,
+    gpointer data, guint size, GstMatroskaDemux * demux);
 static GstCaps *gst_matroska_demux_audio_caps (GstMatroskaTrackAudioContext
     * audiocontext,
-    const gchar * codec_id, gpointer data, guint size, gchar ** codec_name);
+    const gchar * codec_id,
+    gpointer data, guint size, GstMatroskaDemux * demux);
 static GstCaps *gst_matroska_demux_complex_caps (GstMatroskaTrackComplexContext
     * complexcontext, const gchar * codec_id, gpointer data, guint size);
 static GstCaps
@@ -297,8 +299,6 @@ gst_matroska_demux_add_stream (GstMatroskaDemux * demux)
   gchar *padname = NULL;
   gboolean res = TRUE;
   guint32 id;
-  GstTagList *list = NULL;
-  gchar *codec = NULL;
 
   if (demux->num_streams >= GST_MATROSKA_DEMUX_MAX_STREAMS) {
     GST_WARNING ("Maximum number of streams (%d) exceeded, skipping",
@@ -313,7 +313,6 @@ gst_matroska_demux_add_stream (GstMatroskaDemux * demux)
   context->index = demux->num_streams;
   context->type = 0;            /* no type yet */
   context->default_duration = 0;
-  context->pos = 0;
   demux->num_streams++;
 
   /* start with the master */
@@ -375,13 +374,6 @@ gst_matroska_demux_add_stream (GstMatroskaDemux * demux)
           case GST_MATROSKA_TRACK_TYPE_VIDEO:
             context = (GstMatroskaTrackContext *)
                 g_renew (GstMatroskaTrackVideoContext, context, 1);
-            ((GstMatroskaTrackVideoContext *) context)->display_width = 0;
-            ((GstMatroskaTrackVideoContext *) context)->display_height = 0;
-            ((GstMatroskaTrackVideoContext *) context)->pixel_width = 0;
-            ((GstMatroskaTrackVideoContext *) context)->pixel_height = 0;
-            ((GstMatroskaTrackVideoContext *) context)->eye_mode = 0;
-            ((GstMatroskaTrackVideoContext *) context)->asr_mode = 0;
-            ((GstMatroskaTrackVideoContext *) context)->fourcc = 0;
             break;
           case GST_MATROSKA_TRACK_TYPE_AUDIO:
             context = (GstMatroskaTrackContext *)
@@ -845,13 +837,7 @@ gst_matroska_demux_add_stream (GstMatroskaDemux * demux)
       templ = gst_element_class_get_pad_template (klass, "video_%02d");
       caps = gst_matroska_demux_video_caps (videocontext,
           context->codec_id,
-          context->codec_priv, context->codec_priv_size, &codec);
-      if (codec) {
-        list = gst_tag_list_new ();
-        gst_tag_list_add (list, GST_TAG_MERGE_REPLACE,
-            GST_TAG_VIDEO_CODEC, codec, NULL);
-        g_free (codec);
-      }
+          context->codec_priv, context->codec_priv_size, demux);
       break;
     }
 
@@ -862,14 +848,7 @@ gst_matroska_demux_add_stream (GstMatroskaDemux * demux)
       templ = gst_element_class_get_pad_template (klass, "audio_%02d");
       caps = gst_matroska_demux_audio_caps (audiocontext,
           context->codec_id,
-          context->codec_priv, context->codec_priv_size, &codec);
-      audiocontext->first_frame = TRUE;
-      if (codec) {
-        list = gst_tag_list_new ();
-        gst_tag_list_add (list, GST_TAG_MERGE_REPLACE,
-            GST_TAG_AUDIO_CODEC, codec, NULL);
-        g_free (codec);
-      }
+          context->codec_priv, context->codec_priv_size, demux);
       break;
     }
 
@@ -900,13 +879,6 @@ gst_matroska_demux_add_stream (GstMatroskaDemux * demux)
       g_assert (0);
   }
 
-  if (context->language) {
-    if (!list)
-      list = gst_tag_list_new ();
-    gst_tag_list_add (list, GST_TAG_MERGE_REPLACE,
-        GST_TAG_LANGUAGE_CODE, context->language, NULL);
-  }
-
   /* the pad in here */
   context->pad = gst_pad_new_from_template (templ, padname);
   context->caps = caps ? caps : gst_caps_new_empty ();
@@ -928,11 +900,6 @@ gst_matroska_demux_add_stream (GstMatroskaDemux * demux)
 
   gst_element_add_pad (GST_ELEMENT (demux), context->pad);
 
-  /* tags */
-  if (list) {
-    gst_element_found_tags_for_pad (GST_ELEMENT (demux), context->pad, 0, list);
-  }
-
   /* tadaah! */
   return TRUE;
 }
@@ -977,6 +944,9 @@ gst_matroska_demux_handle_src_query (GstPad * pad,
   switch (type) {
     case GST_QUERY_TOTAL:
       switch (*format) {
+        case GST_FORMAT_DEFAULT:
+          *format = GST_FORMAT_TIME;
+          /* fall through */
         case GST_FORMAT_TIME:
           *value = demux->duration;
           break;
@@ -988,6 +958,9 @@ gst_matroska_demux_handle_src_query (GstPad * pad,
 
     case GST_QUERY_POSITION:
       switch (*format) {
+        case GST_FORMAT_DEFAULT:
+          *format = GST_FORMAT_TIME;
+          /* fall through */
         case GST_FORMAT_TIME:
           *value = demux->pos;
           break;
@@ -1131,9 +1104,7 @@ gst_matroska_demux_handle_seek_event (GstMatroskaDemux * demux)
       gst_event_ref (event);
       gst_pad_push (demux->src[i]->pad, GST_DATA (event));
     }
-    demux->src[i]->pos = entry->time;
   }
-  demux->pos = entry->time;
 
   gst_event_unref (event);
 
@@ -1291,7 +1262,7 @@ gst_matroska_demux_parse_index (GstMatroskaDemux * demux, gboolean prevent_eos)
           switch (id) {
               /* one single index entry ('point') */
             case GST_MATROSKA_ID_CUETIME:{
-              guint64 time;
+              gint64 time;
 
               if (!gst_ebml_read_uint (ebml, &id, &time)) {
                 res = FALSE;
@@ -1638,47 +1609,21 @@ gst_matroska_demux_parse_metadata (GstMatroskaDemux * demux,
               if (tag && value) {
                 for (i = 0; tag_conv[i].matroska_tagname != NULL; i++) {
                   if (!strcmp (tag_conv[i].matroska_tagname, tag)) {
+                    GValue src = { 0 }
+                    , dest = {
+                    0};
                     const gchar *type = tag_conv[i].gstreamer_tagname;
+                    GType dest_type = gst_tag_get_type (type);
 
-                    if (strcmp (type, GST_TAG_DATE) == 0) {
-                      GDate *date;
-                      guint y, d = 1, m = 1;
-                      gchar *check = value;
-
-                      y = strtoul (check, &check, 10);
-                      if (*check == '-') {
-                        check++;
-                        m = strtoul (check, &check, 10);
-                        if (*check == '-') {
-                          check++;
-                          d = strtoul (check, &check, 10);
-                        }
-                      }
-                      if (*check != '\0')
-                        break;
-                      if (y == 0)
-                        break;
-                      date = g_date_new_dmy (d, m, y);
-                      y = g_date_get_julian (date);
-                      g_date_free (date);
-                      gst_tag_list_add (taglist, GST_TAG_MERGE_APPEND, type, y,
-                          NULL);
-                      have_tags = TRUE;
-                    } else {
-                      GValue src = { 0, };
-                      GValue dest = { 0, };
-                      GType dest_type = gst_tag_get_type (type);
-
-                      g_value_init (&src, G_TYPE_STRING);
-                      g_value_set_string (&src, value);
-                      g_value_init (&dest, dest_type);
-                      g_value_transform (&src, &dest);
-                      g_value_unset (&src);
-                      gst_tag_list_add_values (taglist, GST_TAG_MERGE_APPEND,
-                          type, &dest, NULL);
-                      g_value_unset (&dest);
-                      have_tags = TRUE;
-                    }
+                    g_value_init (&src, G_TYPE_STRING);
+                    g_value_set_string (&src, value);
+                    g_value_init (&dest, dest_type);
+                    g_value_transform (&src, &dest);
+                    g_value_unset (&src);
+                    gst_tag_list_add_values (taglist, GST_TAG_MERGE_APPEND,
+                        type, &dest, NULL);
+                    g_value_unset (&dest);
+                    have_tags = TRUE;
                     break;
                   }
                 }
@@ -1774,7 +1719,10 @@ gst_matroska_ebmlnum_uint (guint8 * data, guint size, guint64 * num)
     n++;
   }
 
-  if (read == num_ffs && total != 0)
+  if (!total)
+    return -1;
+
+  if (read == num_ffs)
     *num = G_MAXUINT64;
   else
     *num = total;
@@ -1801,47 +1749,6 @@ gst_matroska_ebmlnum_sint (guint8 * data, guint size, gint64 * num)
   return res;
 }
 
-/*
- * Mostly used for subtitles. We add void filler data for each
- * lagging stream to make sure we don't deadlock.
- */
-
-static void
-gst_matroska_demux_sync_streams (GstMatroskaDemux * demux)
-{
-  gint stream_nr;
-  GstMatroskaTrackContext *context;
-
-  GST_DEBUG ("Sync to %" GST_TIME_FORMAT, GST_TIME_ARGS (demux->pos));
-
-  for (stream_nr = 0; stream_nr < demux->num_streams; stream_nr++) {
-    context = demux->src[stream_nr];
-    if (context->type != GST_MATROSKA_TRACK_TYPE_SUBTITLE)
-      continue;
-    GST_DEBUG ("Checking for resync on stream %d (%" GST_TIME_FORMAT ")",
-        stream_nr, GST_TIME_ARGS (context->pos));
-
-    /* does it lag? 1 second is a random treshold... */
-    if (context->pos + (GST_SECOND / 2) < demux->pos) {
-      /* send filler */
-      GstEvent *event;
-
-      event = gst_event_new_filler_stamped (context->pos,
-          demux->pos - context->pos);
-      context->pos = demux->pos;
-
-      /* sync */
-      GST_DEBUG ("Synchronizing stream %d with others by sending filler "
-          "at time %" GST_TIME_FORMAT " and duration %" GST_TIME_FORMAT
-          " to time %" GST_TIME_FORMAT, stream_nr,
-          GST_TIME_ARGS (context->pos),
-          GST_TIME_ARGS (demux->pos - context->pos),
-          GST_TIME_ARGS (demux->pos));
-      gst_pad_push (context->pad, GST_DATA (event));
-    }
-  }
-}
-
 static gboolean
 gst_matroska_demux_parse_blockgroup (GstMatroskaDemux * demux,
     guint64 cluster_time)
@@ -1853,8 +1760,7 @@ gst_matroska_demux_parse_blockgroup (GstMatroskaDemux * demux,
   guint64 block_duration = 0;
   GstBuffer *buf = NULL;
   gint stream = 0, n, laces = 0;
-  guint size = 0;
-  gint *lace_size = NULL;
+  guint size = 0, *lace_size = NULL;
   gint64 time = 0;
 
   while (res) {
@@ -1985,16 +1891,15 @@ gst_matroska_demux_parse_blockgroup (GstMatroskaDemux * demux,
                   lace_size[n] = lace_size[n - 1] + snum;
                   total += lace_size[n];
                 }
-                if (n < laces)
-                  lace_size[n] = size - total;
+                lace_size[n] = size - total;
                 break;
               }
             }
             break;
         }
 
-        if (((GstMatroskaTrackAudioContext *) demux->src[stream])->first_frame
-            && (!strcmp (demux->src[stream]->codec_id,
+        if ((cluster_time + time == 0) &&
+            (!strcmp (demux->src[stream]->codec_id,
                     GST_MATROSKA_CODEC_ID_AUDIO_VORBIS))) {
           /* start of the stream and vorbis audio, need to send the codec_priv
            * data as first three packets */
@@ -2003,8 +1908,6 @@ gst_matroska_demux_parse_blockgroup (GstMatroskaDemux * demux,
           gint i;
           GstBuffer *priv;
 
-          ((GstMatroskaTrackAudioContext *) demux->src[stream])->first_frame =
-              FALSE;
           p = (unsigned char *) demux->src[stream]->codec_priv;
           offset = 3;
           for (i = 0; i < 2; i++) {
@@ -2071,76 +1974,21 @@ gst_matroska_demux_parse_blockgroup (GstMatroskaDemux * demux,
       duration = demux->src[stream]->default_duration;
     }
     for (n = 0; n < laces; n++) {
-      GstBuffer *sub;
-
-      if (lace_size[n] == 0)
-        continue;
-
-      sub = gst_buffer_create_sub (buf,
-          GST_BUFFER_SIZE (buf) - size, lace_size[n]);
+      GstBuffer *sub = gst_buffer_create_sub (buf,
+          GST_BUFFER_SIZE (buf) - size,
+          lace_size[n]);
 
       if (cluster_time != GST_CLOCK_TIME_NONE) {
         if (time < 0 && (-time) > cluster_time)
           GST_BUFFER_TIMESTAMP (sub) = cluster_time;
         else
           GST_BUFFER_TIMESTAMP (sub) = cluster_time + time;
-
-        demux->pos = GST_BUFFER_TIMESTAMP (sub);
-      }
-      demux->src[stream]->pos = demux->pos;
-      gst_matroska_demux_sync_streams (demux);
-
-      if (!strcmp (demux->src[stream]->codec_id,
-              GST_MATROSKA_CODEC_ID_AUDIO_WAVPACK4)) {
-        GstBuffer *newbuf;
-        guint8 *data;
-
-        /* we need to reconstruct the header of the wavpack block */
-        Wavpack4Header wvh;
-
-        wvh.ck_id[0] = 'w';
-        wvh.ck_id[1] = 'v';
-        wvh.ck_id[2] = 'p';
-        wvh.ck_id[3] = 'k';
-        /* -20 because ck_size is the size of the wavpack block -8
-         * and lace_size is the size of the wavpack block + 12
-         * (the three guint32 of the header that already are in the buffer) */
-        wvh.ck_size = lace_size[n] + sizeof (Wavpack4Header) - 20;
-        wvh.version = GST_READ_UINT16_LE (demux->src[stream]->codec_priv);
-        wvh.track_no = 0;
-        wvh.index_no = 0;
-        wvh.total_samples = -1;
-        wvh.block_index = 0;
-        /* block_samples, flags and crc are already in the buffer */
-        newbuf =
-            gst_buffer_new_and_alloc (lace_size[n] + sizeof (Wavpack4Header) -
-            12);
-        data = GST_BUFFER_DATA (newbuf);
-        data[0] = 'w';
-        data[1] = 'v';
-        data[2] = 'p';
-        data[3] = 'k';
-        GST_WRITE_UINT32_LE (data + 4, wvh.ck_size);
-        GST_WRITE_UINT16_LE (data + 8, wvh.version);
-        GST_WRITE_UINT8 (data + 10, wvh.track_no);
-        GST_WRITE_UINT8 (data + 11, wvh.index_no);
-        GST_WRITE_UINT32_LE (data + 12, wvh.total_samples);
-        GST_WRITE_UINT32_LE (data + 16, wvh.block_index);
-        g_memmove (data + 20, GST_BUFFER_DATA (sub), lace_size[n]);
-        GST_BUFFER_TIMESTAMP (newbuf) = GST_BUFFER_TIMESTAMP (sub);
-        sub = newbuf;
       }
 
-      /* FIXME: do all laces have the same lenght? */
+      /* do all laces have the same lenght? */
       if (duration) {
         GST_BUFFER_DURATION (sub) = duration / laces;
-        demux->src[stream]->pos += GST_BUFFER_DURATION (sub);
       }
-      GST_DEBUG ("Pushing data of size %d for stream %d, time=%"
-          GST_TIME_FORMAT " and duration=%" GST_TIME_FORMAT,
-          GST_BUFFER_SIZE (sub), stream,
-          GST_TIME_ARGS (GST_BUFFER_TIMESTAMP (sub)),
-          GST_TIME_ARGS (GST_BUFFER_DURATION (sub)));
       gst_pad_push (demux->src[stream]->pad, GST_DATA (sub));
 
       size -= lace_size[n];
@@ -2259,8 +2107,7 @@ gst_matroska_demux_parse_contents (GstMatroskaDemux * demux)
             case GST_MATROSKA_ID_SEEKID:
               if (!gst_ebml_read_uint (ebml, &id, &t))
                 res = FALSE;
-              else
-                seek_id = t;
+              seek_id = t;
               break;
 
             case GST_MATROSKA_ID_SEEKPOSITION:
@@ -2295,7 +2142,6 @@ gst_matroska_demux_parse_contents (GstMatroskaDemux * demux)
           case GST_MATROSKA_ID_TAGS:{
             guint level_up = demux->level_up;
             guint64 before_pos, length;
-            guint32 id_cache = ebml->id_cache;
             GstEbmlLevel *level;
             GstEvent *event;
 
@@ -2378,7 +2224,6 @@ gst_matroska_demux_parse_contents (GstMatroskaDemux * demux)
               return FALSE;
             gst_event_unref (event);
             demux->level_up = level_up;
-            ebml->id_cache = id_cache;
             break;
           }
 
@@ -2488,10 +2333,6 @@ gst_matroska_demux_loop_stream (GstMatroskaDemux * demux)
           demux->state = GST_MATROSKA_DEMUX_STATE_DATA;
           gst_element_no_more_pads (GST_ELEMENT (demux));
         } else {
-          if (!gst_ebml_read_reserve (ebml)) {
-            res = FALSE;
-            break;
-          }
           if (!gst_ebml_read_master (ebml, &id)) {
             res = FALSE;
             break;
@@ -2545,7 +2386,7 @@ gst_matroska_demux_loop (GstElement * element)
 
 static GstCaps *
 gst_matroska_demux_video_caps (GstMatroskaTrackVideoContext * videocontext,
-    const gchar * codec_id, gpointer data, guint size, gchar ** codec_name)
+    const gchar * codec_id, gpointer data, guint size, GstMatroskaDemux * demux)
 {
   GstMatroskaTrackContext *context = (GstMatroskaTrackContext *) videocontext;
   GstCaps *caps = NULL;
@@ -2554,6 +2395,9 @@ gst_matroska_demux_video_caps (GstMatroskaTrackVideoContext * videocontext,
     gst_riff_strf_vids *vids = NULL;
 
     if (data) {
+      char *codec_name = NULL;
+      GstTagList *list = gst_tag_list_new ();
+
       vids = (gst_riff_strf_vids *) data;
 
       /* assure size is big enough */
@@ -2581,7 +2425,14 @@ gst_matroska_demux_video_caps (GstMatroskaTrackVideoContext * videocontext,
       vids->imp_colors = GUINT32_FROM_LE (vids->imp_colors);
 
       caps = gst_riff_create_video_caps (vids->compression, NULL, vids,
-          codec_name);
+          &codec_name);
+      gst_tag_list_add (list, GST_TAG_MERGE_APPEND, GST_TAG_VIDEO_CODEC,
+          codec_name, NULL);
+      if (GST_IS_ELEMENT (demux))
+        gst_element_found_tags (GST_ELEMENT (demux), list);
+      gst_tag_list_free (list);
+      if (codec_name)
+        g_free (codec_name);
     } else {
       caps = gst_riff_create_video_template_caps ();
     }
@@ -2592,13 +2443,7 @@ gst_matroska_demux_video_caps (GstMatroskaTrackVideoContext * videocontext,
 
       switch (videocontext->fourcc) {
         case GST_MAKE_FOURCC ('I', '4', '2', '0'):
-          if (codec_name)
-            *codec_name = g_strdup ("Raw planar YUV 4:2:0");
-          fourcc = videocontext->fourcc;
-          break;
         case GST_MAKE_FOURCC ('Y', 'U', 'Y', '2'):
-          if (codec_name)
-            *codec_name = g_strdup ("Raw packed YUV 4:2:2");
           fourcc = videocontext->fourcc;
           break;
 
@@ -2617,8 +2462,6 @@ gst_matroska_demux_video_caps (GstMatroskaTrackVideoContext * videocontext,
   } else if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_VIDEO_MPEG4_SP)) {
     caps = gst_caps_new_simple ("video/x-divx",
         "divxversion", G_TYPE_INT, 4, NULL);
-    if (codec_name)
-      *codec_name = g_strdup ("MPEG-4 simple profile");
   } else if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_VIDEO_MPEG4_ASP) ||
       !strcmp (codec_id, GST_MATROSKA_CODEC_ID_VIDEO_MPEG4_AP)) {
     caps = gst_caps_new_full (gst_structure_new ("video/x-divx",
@@ -2627,19 +2470,11 @@ gst_matroska_demux_video_caps (GstMatroskaTrackVideoContext * videocontext,
         gst_structure_new ("video/mpeg",
             "mpegversion", G_TYPE_INT, 4,
             "systemstream", G_TYPE_BOOLEAN, FALSE, NULL), NULL);
-    if (codec_name) {
-      if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_VIDEO_MPEG4_ASP))
-        *codec_name = g_strdup ("MPEG-4 advanced simple profile");
-      else
-        *codec_name = g_strdup ("MPEG-4 advanced profile");
-    }
   } else if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_VIDEO_MSMPEG4V3)) {
     caps = gst_caps_new_full (gst_structure_new ("video/x-divx",
             "divxversion", G_TYPE_INT, 3, NULL),
         gst_structure_new ("video/x-msmpeg",
             "msmpegversion", G_TYPE_INT, 43, NULL), NULL);
-    if (codec_name)
-      *codec_name = g_strdup ("Microsoft MPEG-4 v.3");
   } else if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_VIDEO_MPEG1) ||
       !strcmp (codec_id, GST_MATROSKA_CODEC_ID_VIDEO_MPEG2)) {
     gint mpegversion = -1;
@@ -2654,24 +2489,8 @@ gst_matroska_demux_video_caps (GstMatroskaTrackVideoContext * videocontext,
     caps = gst_caps_new_simple ("video/mpeg",
         "systemstream", G_TYPE_BOOLEAN, FALSE,
         "mpegversion", G_TYPE_INT, mpegversion, NULL);
-    if (codec_name)
-      *codec_name = g_strdup_printf ("MPEG-%d video", mpegversion);
   } else if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_VIDEO_MJPEG)) {
-    caps = gst_caps_new_simple ("image/jpeg", NULL);
-    if (codec_name)
-      *codec_name = g_strdup ("Motion-JPEG");
-  } else if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_VIDEO_MPEG4_AVC)) {
-    caps = gst_caps_new_simple ("video/x-h264", NULL);
-    if (data) {
-      GstBuffer *priv = gst_buffer_new_and_alloc (size);
-
-      memcpy (GST_BUFFER_DATA (priv), data, size);
-      gst_caps_set_simple (caps, "codec_data", GST_TYPE_BUFFER, priv, NULL);
-      gst_buffer_unref (priv);
-
-    }
-    if (codec_name)
-      *codec_name = g_strdup ("H264");
+    caps = gst_caps_new_simple ("video/x-jpeg", NULL);
   } else {
     GST_WARNING ("Unknown codec '%s', cannot build Caps", codec_id);
     return NULL;
@@ -2735,63 +2554,9 @@ gst_matroska_demux_video_caps (GstMatroskaTrackVideoContext * videocontext,
   return caps;
 }
 
-/*
- * Some AAC specific code... *sigh*
- */
-
-static gint
-aac_rate_idx (gint rate)
-{
-  if (92017 <= rate)
-    return 0;
-  else if (75132 <= rate)
-    return 1;
-  else if (55426 <= rate)
-    return 2;
-  else if (46009 <= rate)
-    return 3;
-  else if (37566 <= rate)
-    return 4;
-  else if (27713 <= rate)
-    return 5;
-  else if (23004 <= rate)
-    return 6;
-  else if (18783 <= rate)
-    return 7;
-  else if (13856 <= rate)
-    return 8;
-  else if (11502 <= rate)
-    return 9;
-  else if (9391 <= rate)
-    return 10;
-  else
-    return 11;
-}
-
-static gint
-aac_profile_idx (const gchar * codec_id)
-{
-  gint profile;
-
-  if (strlen (codec_id) <= 12)
-    profile = 3;
-  else if (!strncmp (&codec_id[12], "MAIN", 4))
-    profile = 0;
-  else if (!strncmp (&codec_id[12], "LC", 2))
-    profile = 1;
-  else if (!strncmp (&codec_id[12], "SSR", 3))
-    profile = 2;
-  else
-    profile = 3;
-
-  return profile;
-}
-
-#define AAC_SYNC_EXTENSION_TYPE 0x02b7
-
 static GstCaps *
 gst_matroska_demux_audio_caps (GstMatroskaTrackAudioContext * audiocontext,
-    const gchar * codec_id, gpointer data, guint size, gchar ** codec_name)
+    const gchar * codec_id, gpointer data, guint size, GstMatroskaDemux * demux)
 {
   GstMatroskaTrackContext *context = (GstMatroskaTrackContext *) audiocontext;
   GstCaps *caps = NULL;
@@ -2812,8 +2577,6 @@ gst_matroska_demux_audio_caps (GstMatroskaTrackAudioContext * audiocontext,
 
     caps = gst_caps_new_simple ("audio/mpeg",
         "mpegversion", G_TYPE_INT, 1, "layer", G_TYPE_INT, layer, NULL);
-    if (codec_name)
-      *codec_name = g_strdup_printf ("MPEG-1 layer %d", layer);
   } else if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_AUDIO_PCM_INT_BE) ||
       !strcmp (codec_id, GST_MATROSKA_CODEC_ID_AUDIO_PCM_INT_LE)) {
     gint endianness = -1;
@@ -2836,9 +2599,6 @@ gst_matroska_demux_audio_caps (GstMatroskaTrackAudioContext * audiocontext,
           "depth = (int) { 8, 16 }, " "width = (int) { 8, 16 }");
     }
     gst_caps_set_simple (caps, "endianness", G_TYPE_INT, endianness, NULL);
-    if (codec_name && audiocontext)
-      *codec_name = g_strdup_printf ("Raw %d-bits PCM audio",
-          audiocontext->bitdepth);
   } else if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_AUDIO_PCM_FLOAT)) {
     caps = gst_caps_new_simple ("audio/x-raw-float",
         "endianness", G_TYPE_INT, G_BYTE_ORDER,
@@ -2849,25 +2609,19 @@ gst_matroska_demux_audio_caps (GstMatroskaTrackAudioContext * audiocontext,
     } else {
       gst_caps_set_simple (caps, "width", GST_TYPE_INT_RANGE, 32, 64, NULL);
     }
-    if (codec_name && audiocontext)
-      *codec_name = g_strdup_printf ("Raw %d-bits floating-point audio",
-          audiocontext->bitdepth);
   } else if (!strncmp (codec_id, GST_MATROSKA_CODEC_ID_AUDIO_AC3,
-          strlen (GST_MATROSKA_CODEC_ID_AUDIO_AC3))) {
+          strlen (GST_MATROSKA_CODEC_ID_AUDIO_AC3)) ||
+      !strcmp (codec_id, GST_MATROSKA_CODEC_ID_AUDIO_DTS)) {
     caps = gst_caps_new_simple ("audio/x-ac3", NULL);
-    if (codec_name)
-      *codec_name = g_strdup ("AC-3 audio");
-  } else if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_AUDIO_DTS)) {
-    caps = gst_caps_new_simple ("audio/x-dts", NULL);
-    if (codec_name)
-      *codec_name = g_strdup ("DTS audio");
   } else if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_AUDIO_VORBIS)) {
     caps = gst_caps_new_simple ("audio/x-vorbis", NULL);
-    /* vorbis decoder does tags */
   } else if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_AUDIO_ACM)) {
     gst_riff_strf_auds *auds = NULL;
 
     if (data) {
+      char *codec_name = NULL;
+      GstTagList *list = gst_tag_list_new ();
+
       auds = (gst_riff_strf_auds *) data;
 
       /* little-endian -> byte-order */
@@ -2878,7 +2632,14 @@ gst_matroska_demux_audio_caps (GstMatroskaTrackAudioContext * audiocontext,
       auds->blockalign = GUINT16_FROM_LE (auds->blockalign);
       auds->size = GUINT16_FROM_LE (auds->size);
 
-      caps = gst_riff_create_audio_caps (auds->format, NULL, auds, codec_name);
+      caps = gst_riff_create_audio_caps (auds->format, NULL, auds, &codec_name);
+      gst_tag_list_add (list, GST_TAG_MERGE_APPEND, GST_TAG_AUDIO_CODEC,
+          codec_name, NULL);
+      if (GST_IS_ELEMENT (demux))
+        gst_element_found_tags (GST_ELEMENT (demux), list);
+      gst_tag_list_free (list);
+      if (codec_name)
+        g_free (codec_name);
     } else {
       caps = gst_riff_create_audio_template_caps ();
     }
@@ -2887,50 +2648,18 @@ gst_matroska_demux_audio_caps (GstMatroskaTrackAudioContext * audiocontext,
       !strncmp (codec_id, GST_MATROSKA_CODEC_ID_AUDIO_MPEG4,
           strlen (GST_MATROSKA_CODEC_ID_AUDIO_MPEG4))) {
     gint mpegversion = -1;
-    GstBuffer *priv = NULL;
 
     if (!strncmp (codec_id, GST_MATROSKA_CODEC_ID_AUDIO_MPEG2,
             strlen (GST_MATROSKA_CODEC_ID_AUDIO_MPEG2)))
       mpegversion = 2;
     else if (!strncmp (codec_id, GST_MATROSKA_CODEC_ID_AUDIO_MPEG4,
-            strlen (GST_MATROSKA_CODEC_ID_AUDIO_MPEG4))) {
-      gint rate_idx, profile;
-      guint8 *data;
-
+            strlen (GST_MATROSKA_CODEC_ID_AUDIO_MPEG4)))
       mpegversion = 4;
-
-      if (audiocontext) {
-        /* make up decoderspecificdata */
-        priv = gst_buffer_new_and_alloc (5);
-        data = GST_BUFFER_DATA (priv);
-        rate_idx = aac_rate_idx (audiocontext->samplerate);
-        profile = aac_profile_idx (codec_id);
-
-        data[0] = ((profile + 1) << 3) | ((rate_idx & 0xE) >> 1);
-        data[1] = ((rate_idx & 0x1) << 7) | (audiocontext->channels << 3);
-
-        if (g_strrstr (codec_id, "SBR")) {
-          /* HE-AAC (aka SBR AAC) */
-          audiocontext->samplerate *= 2;
-          rate_idx = aac_rate_idx (audiocontext->samplerate);
-          data[2] = AAC_SYNC_EXTENSION_TYPE >> 3;
-          data[3] = ((AAC_SYNC_EXTENSION_TYPE & 0x07) << 5) | 5;
-          data[4] = (1 << 7) | (rate_idx << 3);
-        } else {
-          GST_BUFFER_SIZE (priv) = 2;
-        }
-      }
-    } else
+    else
       g_assert (0);
 
     caps = gst_caps_new_simple ("audio/mpeg",
-        "mpegversion", G_TYPE_INT, mpegversion,
-        "framed", G_TYPE_BOOLEAN, TRUE, NULL);
-    if (priv) {
-      gst_caps_set_simple (caps, "codec_data", GST_TYPE_BUFFER, priv, NULL);
-    }
-    if (codec_name)
-      *codec_name = g_strdup_printf ("MPEG-%d AAC audio", mpegversion);
+        "mpegversion", G_TYPE_INT, mpegversion, NULL);
   } else if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_AUDIO_TTA)) {
     if (audiocontext != NULL) {
       caps = gst_caps_new_simple ("audio/x-tta",
@@ -2939,21 +2668,9 @@ gst_matroska_demux_audio_caps (GstMatroskaTrackAudioContext * audiocontext,
       caps = gst_caps_from_string ("audio/x-tta, "
           "width = (int) { 8, 16, 24 }");
     }
-    if (codec_name)
-      *codec_name = g_strdup ("TTA audio");
-  } else if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_AUDIO_WAVPACK4)) {
-    if (audiocontext != NULL) {
-      caps = gst_caps_new_simple ("audio/x-wavpack",
-          "width", G_TYPE_INT, audiocontext->bitdepth,
-          "framed", G_TYPE_BOOLEAN, TRUE, NULL);
-    } else {
-      caps = gst_caps_from_string ("audio/x-wavpack, "
-          "width = (int) { 8, 16, 24 }, " "framed = (boolean) true");
-    }
-    if (codec_name)
-      *codec_name = g_strdup ("Wavpack audio");
   } else {
     GST_WARNING ("Unknown codec '%s', cannot build Caps", codec_id);
+    g_print ("Codec=%s\n", codec_id);
     return NULL;
   }
 
@@ -2995,13 +2712,9 @@ static GstCaps *
 gst_matroska_demux_subtitle_caps (GstMatroskaTrackSubtitleContext *
     subtitlecontext, const gchar * codec_id, gpointer data, guint size)
 {
-  /*GstMatroskaTrackContext *context =
-     (GstMatroskaTrackContext *) subtitlecontext; */
   GstCaps *caps = NULL;
 
-  if (!strcmp (codec_id, GST_MATROSKA_CODEC_ID_SUBTITLE_UTF8)) {
-    caps = gst_caps_new_simple ("text/plain", NULL);
-  }
+  //..
 
   return caps;
 }
@@ -3035,7 +2748,6 @@ gst_matroska_demux_plugin_init (GstPlugin * plugin)
     GST_MATROSKA_CODEC_ID_VIDEO_UNCOMPRESSED,
     GST_MATROSKA_CODEC_ID_VIDEO_MPEG4_SP,
     GST_MATROSKA_CODEC_ID_VIDEO_MPEG4_ASP,
-    GST_MATROSKA_CODEC_ID_VIDEO_MPEG4_AVC,
     GST_MATROSKA_CODEC_ID_VIDEO_MSMPEG4V3,
     GST_MATROSKA_CODEC_ID_VIDEO_MPEG1,
     GST_MATROSKA_CODEC_ID_VIDEO_MPEG2,
@@ -3055,7 +2767,6 @@ gst_matroska_demux_plugin_init (GstPlugin * plugin)
         GST_MATROSKA_CODEC_ID_AUDIO_VORBIS,
         GST_MATROSKA_CODEC_ID_AUDIO_TTA,
         GST_MATROSKA_CODEC_ID_AUDIO_MPEG2, GST_MATROSKA_CODEC_ID_AUDIO_MPEG4,
-        GST_MATROSKA_CODEC_ID_AUDIO_WAVPACK4,
         /* TODO: AC3-9/10, Real, Musepack, Quicktime */
         /* FILLME */
   NULL,}
@@ -3063,8 +2774,7 @@ gst_matroska_demux_plugin_init (GstPlugin * plugin)
     /* FILLME */
   NULL,}
   , *subtitle_id[] = {
-    GST_MATROSKA_CODEC_ID_SUBTITLE_UTF8,
-        /* FILLME */
+    /* FILLME */
   NULL,};
 
   /* this filter needs the riff parser */
