@@ -190,7 +190,7 @@ gst_decode_bin_class_init (GstDecodeBinClass * klass)
       g_signal_new ("new-decoded-pad", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST,
       G_STRUCT_OFFSET (GstDecodeBinClass, new_decoded_pad), NULL, NULL,
-      gst_play_marshal_VOID__OBJECT_BOOLEAN, G_TYPE_NONE, 2, GST_TYPE_PAD,
+      gst_play_marshal_VOID__OBJECT_BOOLEAN, G_TYPE_NONE, 2, G_TYPE_OBJECT,
       G_TYPE_BOOLEAN);
   gst_decode_bin_signals[SIGNAL_REMOVED_DECODED_PAD] =
       g_signal_new ("removed-decoded-pad", G_TYPE_FROM_CLASS (klass),
@@ -242,8 +242,7 @@ gst_decode_bin_factory_filter (GstPluginFeature * feature,
 
   klass = gst_element_factory_get_klass (GST_ELEMENT_FACTORY (feature));
   /* only demuxers and decoders can play */
-  if (strstr (klass, "Demux") == NULL &&
-      strstr (klass, "Decoder") == NULL && strstr (klass, "Parse") == NULL) {
+  if (strstr (klass, "Demux") == NULL && strstr (klass, "Decoder") == NULL) {
     return FALSE;
   }
 
@@ -259,13 +258,7 @@ gst_decode_bin_factory_filter (GstPluginFeature * feature,
 static gint
 compare_ranks (GstPluginFeature * f1, GstPluginFeature * f2)
 {
-  gint diff;
-
-  diff = gst_plugin_feature_get_rank (f2) - gst_plugin_feature_get_rank (f1);
-  if (diff != 0)
-    return diff;
-  return strcmp (gst_plugin_feature_get_name (f2),
-      gst_plugin_feature_get_name (f1));
+  return gst_plugin_feature_get_rank (f2) - gst_plugin_feature_get_rank (f1);
 }
 
 static void
@@ -370,8 +363,6 @@ find_compatibles (GstDecodeBin * decode_bin, const GstCaps * caps)
         if (!gst_caps_is_empty (intersect)) {
           /* non empty intersection, we can use this element */
           to_try = g_list_append (to_try, factory);
-          gst_caps_free (intersect);
-          break;
         }
         gst_caps_free (intersect);
       }
@@ -397,9 +388,6 @@ close_pad_link (GstElement * element, GstPad * pad, GstCaps * caps,
   GstStructure *structure;
   const gchar *mimetype;
 
-  if (!strncmp (gst_pad_get_name (pad), "current_", 8))
-    return;
-
   /* the caps is empty, this means the pad has no type, we can only
    * decide to fire the unknown_type signal. */
   if (caps == NULL || gst_caps_is_empty (caps)) {
@@ -425,8 +413,7 @@ close_pad_link (GstElement * element, GstPad * pad, GstCaps * caps,
   /* first see if this is raw. If the type is raw, we can
    * create a ghostpad for this pad. */
   if (g_str_has_prefix (mimetype, "video/x-raw") ||
-      g_str_has_prefix (mimetype, "audio/x-raw") ||
-      g_str_has_prefix (mimetype, "text/plain")) {
+      g_str_has_prefix (mimetype, "audio/x-raw")) {
     gchar *padname;
     GstPad *ghost;
 
@@ -523,7 +510,7 @@ try_to_link_1 (GstDecodeBin * decode_bin, GstPad * pad, GList * factories)
         }
       }
       /* make sure we catch unlink signals */
-      sig = g_signal_connect (G_OBJECT (GST_PAD_REALIZE (pad)), "unlinked",
+      sig = g_signal_connect (G_OBJECT (pad), "unlinked",
           G_CALLBACK (unlinked), decode_bin);
       /* keep a ref to the signal id so that we can disconnect the signal callback */
       g_object_set_data (G_OBJECT (pad), "unlinked_id", GINT_TO_POINTER (sig));
@@ -649,15 +636,11 @@ static void
 new_pad (GstElement * element, GstPad * pad, GstDynamic * dynamic)
 {
   GstDecodeBin *decode_bin = dynamic->decode_bin;
-  GstCaps *caps;
 
   /* see if any more pending dynamic connections exist */
   gboolean more = gst_decode_bin_is_dynamic (decode_bin);
 
-  caps = gst_pad_get_caps (pad);
-  close_pad_link (element, pad, caps, decode_bin, more);
-  if (caps)
-    gst_caps_free (caps);
+  close_pad_link (element, pad, gst_pad_get_caps (pad), decode_bin, more);
 }
 
 /* this signal is fired when an element signals the no_more_pads signal.
@@ -829,7 +812,6 @@ close_link (GstElement * element, GstDecodeBin * decode_bin)
   /* now loop over all the pads we need to connect */
   for (pads = to_connect; pads; pads = g_list_next (pads)) {
     GstPad *pad = GST_PAD (pads->data);
-    GstCaps *caps;
 
     /* we have more pads if we have more than 1 pad to connect or
      * dynamics. If we have only 1 pad and no dynamics, more will be
@@ -841,10 +823,7 @@ close_link (GstElement * element, GstDecodeBin * decode_bin)
         gst_pad_get_name (pad));
 
     /* continue autoplugging on the pads */
-    caps = gst_pad_get_caps (pad);
-    close_pad_link (element, pad, caps, decode_bin, more);
-    if (caps)
-      gst_caps_free (caps);
+    close_pad_link (element, pad, gst_pad_get_caps (pad), decode_bin, more);
   }
 
   g_list_free (to_connect);
