@@ -29,11 +29,24 @@
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include <fcntl.h>
-#include <sys/soundcard.h>
 #include <unistd.h>
 #include <errno.h>
 #include <string.h>
 
+#ifdef HAVE_OSS_INCLUDE_IN_SYS
+#include <sys/soundcard.h>
+#else
+
+#ifdef HAVE_OSS_INCLUDE_IN_ROOT
+#include <soundcard.h>
+#else
+
+#include <machine/soundcard.h>
+
+#endif /* HAVE_OSS_INCLUDE_IN_ROOT */
+
+#endif /* HAVE_OSS_INCLUDE_IN_SYS */
+
 #include <gst/propertyprobe/propertyprobe.h>
 
 #include "gstosselement.h"
@@ -44,12 +57,12 @@ enum
   ARG_0,
   ARG_DEVICE,
   ARG_MIXERDEV,
-  ARG_DEVICE_NAME,
+  ARG_DEVICE_NAME
 };
 
 /* elementfactory information */
 static GstElementDetails gst_osselement_details =
-GST_ELEMENT_DETAILS ("Audio Mixer (OSS)",
+GST_ELEMENT_DETAILS ("OSS Mixer",
     "Generic/Audio",
     "OSS-based mixer element",
     "Ronald Bultje <rbultje@ronald.bitfreak.net>");
@@ -59,7 +72,7 @@ static void gst_osselement_class_init (GstOssElementClass * klass);
 
 static void gst_ossprobe_interface_init (GstPropertyProbeInterface * iface);
 static void gst_osselement_init (GstOssElement * oss);
-static void gst_osselement_dispose (GObject * object);
+static void gst_osselement_finalize (GObject * object);
 
 static void gst_osselement_set_property (GObject * object,
     guint prop_id, const GValue * value, GParamSpec * pspec);
@@ -151,7 +164,7 @@ gst_osselement_class_init (GstOssElementClass * klass)
 
   gobject_class->set_property = gst_osselement_set_property;
   gobject_class->get_property = gst_osselement_get_property;
-  gobject_class->dispose = gst_osselement_dispose;
+  gobject_class->finalize = gst_osselement_finalize;
 
   gstelement_class->change_state = gst_osselement_change_state;
 }
@@ -300,6 +313,7 @@ gst_osselement_class_probe_devices (GstOssElementClass * klass, gboolean check)
           combi = g_new0 (GstOssDeviceCombination, 1);
           combi->dsp = dsp;
           combi->mixer = mixer;
+          combi->dev = mixer ? mixer_dev : dsp_dev;
           device_combinations = device_combination_append (device_combinations,
               combi);
         } else {
@@ -420,14 +434,14 @@ gst_osselement_init (GstOssElement * oss)
 }
 
 static void
-gst_osselement_dispose (GObject * object)
+gst_osselement_finalize (GObject * object)
 {
   GstOssElement *oss = (GstOssElement *) object;
 
   g_free (oss->device);
   g_free (oss->mixer_dev);
 
-  G_OBJECT_CLASS (parent_class)->dispose (object);
+  G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 void
@@ -440,8 +454,9 @@ gst_osselement_reset (GstOssElement * oss)
   oss->depth = 16;
   oss->channels = 2;
   oss->rate = 44100;
-  oss->fragment = 6;
+  oss->fragment = 0;
   oss->bps = 0;
+  oss->sample_width = 0;
 
 /* AFMT_*_BE not available on all OSS includes (e.g. FBSD) */
 #ifdef WORDS_BIGENDIAN
@@ -531,6 +546,7 @@ gst_osselement_parse_caps (GstOssElement * oss, const GstCaps * caps)
   gst_structure_get_int (structure, "channels", &oss->channels);
   gst_structure_get_int (structure, "rate", &oss->rate);
 
+  oss->sample_width = bps * oss->channels;
   oss->bps = bps * oss->channels * oss->rate;
   oss->format = format;
 
@@ -585,21 +601,26 @@ gst_osselement_sync_parms (GstOssElement * oss)
   gint target_format;
   gint target_channels;
   gint target_rate;
-  gint fragscale, frag_ln;
+
+  /* gint fragscale, frag_ln; */
 
   if (oss->fd == -1)
     return FALSE;
 
-  if (oss->fragment >> 16)
+  if ((oss->fragment & 0xFFFF) == 0) {
+    frag = 0;
+  } else if (oss->fragment >> 16) {
     frag = oss->fragment;
-  else
+  } else {
     frag = 0x7FFF0000 | oss->fragment;
+  }
 
   GST_INFO
       ("osselement: setting sound card to %dHz %d format %s (%08x fragment)",
       oss->rate, oss->format, (oss->channels == 2) ? "stereo" : "mono", frag);
 
-  ioctl (oss->fd, SNDCTL_DSP_SETFRAGMENT, &frag);
+  if (frag)
+    ioctl (oss->fd, SNDCTL_DSP_SETFRAGMENT, &frag);
   ioctl (oss->fd, SNDCTL_DSP_RESET, 0);
 
   target_format = oss->format;
@@ -618,6 +639,9 @@ gst_osselement_sync_parms (GstOssElement * oss)
     ioctl (oss->fd, SNDCTL_DSP_GETISPACE, &space);
   }
 
+#if 0
+  /* FIXME: make the current fragment info available somehow
+   * the current way overrides preset values and that sucks */
   /* calculate new fragment using a poor man's logarithm function */
   fragscale = 1;
   frag_ln = 0;
@@ -626,6 +650,7 @@ gst_osselement_sync_parms (GstOssElement * oss)
     frag_ln++;
   }
   oss->fragment = space.fragstotal << 16 | frag_ln;
+#endif
 
   GST_INFO ("osselement: set sound card to %dHz, %d format, %s "
       "(%d bytes buffer, %08x fragment)",
@@ -633,7 +658,7 @@ gst_osselement_sync_parms (GstOssElement * oss)
       (oss->channels == 2) ? "stereo" : "mono", space.bytes, oss->fragment);
 
   oss->fragment_time = (GST_SECOND * oss->fragment_size) / oss->bps;
-  GST_INFO ("fragment time %u %" G_GUINT64_FORMAT "\n",
+  GST_INFO ("fragment time %u %" G_GUINT64_FORMAT,
       oss->bps, oss->fragment_time);
 
   if (target_format != oss->format ||
@@ -977,7 +1002,21 @@ gst_osselement_change_state (GstElement * element)
 
 
 #if 0
+
+#ifdef HAVE_OSS_INCLUDE_IN_SYS
 #include <sys/soundcard.h>
+#else
+
+#ifdef HAVE_OSS_INCLUDE_IN_ROOT
+#include <soundcard.h>
+#else
+
+#include <machine/soundcard.h>
+
+#endif /* HAVE_OSS_INCLUDE_IN_ROOT */
+
+#endif /* HAVE_OSS_INCLUDE_IN_SYS */
+
 #include <unistd.h>
 #include <fcntl.h>
 #include <stdio.h>
@@ -1089,7 +1128,7 @@ gst_osselement_probe_caps (GstOssElement * oss)
 
   if (gst_caps_is_empty (caps)) {
     GST_ELEMENT_ERROR (oss, RESOURCE, SETTINGS,
-        (_("Your oss device could not be probed correctly")), (NULL));
+        (_("Your OSS device could not be probed correctly")), (NULL));
     return;
   }
   GST_DEBUG ("probed caps: %" GST_PTR_FORMAT, caps);
@@ -1168,7 +1207,26 @@ gst_osselement_rate_probe_check (GstOssProbe * probe)
   probe->min = gst_osselement_rate_check_rate (probe, 1000);
   n_checks++;
   probe->max = gst_osselement_rate_check_rate (probe, 100000);
+  /* a little bug workaround */
+  {
+    int max;
+
+    max = gst_osselement_rate_check_rate (probe, 48000);
+    if (max > probe->max) {
+      GST_ERROR
+          ("Driver bug recognized (driver does not round rates correctly).  Please file a bug report.");
+      probe->max = max;
+    }
+  }
   n_checks++;
+  if (probe->min == -1 || probe->max == -1) {
+    /* This is a workaround for drivers that return -EINVAL (or another
+     * error) for rates outside of [8000,48000].  If this fails, the
+     * driver is seriously buggy, and probably doesn't work with other
+     * media libraries/apps.  */
+    probe->min = gst_osselement_rate_check_rate (probe, 8000);
+    probe->max = gst_osselement_rate_check_rate (probe, 48000);
+  }
   if (probe->min == -1 || probe->max == -1) {
     GST_DEBUG ("unexpected check_rate error");
     return FALSE;
@@ -1181,7 +1239,7 @@ gst_osselement_rate_probe_check (GstOssProbe * probe)
     int mid;
     int mid_ret;
 
-    GST_DEBUG ("checking [%d,%d]\n", range->min, range->max);
+    GST_DEBUG ("checking [%d,%d]", range->min, range->max);
 
     mid = (range->min + range->max) / 2;
     mid_ret = gst_osselement_rate_check_rate (probe, mid);
@@ -1196,7 +1254,7 @@ gst_osselement_rate_probe_check (GstOssProbe * probe)
 
       exact_rates++;
       if (exact_rates > max_exact_matches) {
-        GST_DEBUG ("got %d exact rates, assuming all are exact\n",
+        GST_DEBUG ("got %d exact rates, assuming all are exact",
             max_exact_matches);
         result = FALSE;
         g_free (range);
@@ -1274,7 +1332,7 @@ gst_osselement_rate_check_rate (GstOssProbe * probe, int irate)
   if (ret < 0)
     return -1;
 
-  GST_DEBUG ("rate %d -> %d\n", irate, rate);
+  GST_DEBUG ("rate %d -> %d", irate, rate);
 
   if (rate == irate - 1 || rate == irate + 1) {
     rate = irate;
@@ -1295,7 +1353,7 @@ gst_osselement_rate_add_rate (GArray * array, int rate)
     if (val == rate)
       return;
   }
-  GST_DEBUG ("supported rate: %d\n", rate);
+  GST_DEBUG ("supported rate: %d", rate);
   g_array_append_val (array, rate);
 }
 
